.. _performance:

===========
Performance
===========

This section covers various performance optimizations and scaling considerations
for Salt.

.. toctree::
    :maxdepth: 1

    pki_index
    worker_pools
